@@ -3,6 +3,7 @@ from cytra.db import DatabaseAppMixin
 from cytra.auth import AuthAppMixin
 from cytra.cors import CORS
 from cytra.log import LogAppMixin
+from cytra.redis import RedisAppMixin
 
 
 class CytraAppBase(GongishApp):
@@ -32,5 +33,11 @@ class CytraAppBase(GongishApp):
         pass
 
 
-class Application(AuthAppMixin, DatabaseAppMixin, LogAppMixin, CytraAppBase):
+class Application(
+    AuthAppMixin,
+    RedisAppMixin,
+    DatabaseAppMixin,
+    LogAppMixin,
+    CytraAppBase,
+):
     pass
